<?php

namespace src\fortnox\api;

if ( !defined( 'ABSPATH' ) ) die();

use Exception;
use src\fortnox\WF_Plugin;

class WF_Auth
{

    const CLIENT_ID = 'EY09o6u03lry';
    const REFRESH_URL = 'https://apps.fortnox.se/oauth-v1/token';
    /**
     * Get access token
     * @return mixed
     * @throws Exception
     */
	public static function get_access_token()
	{
		$auth_code = get_option( 'fortnox_auth_code'  );
		$client_secret = WF_Plugin::CLIENT_SECRET;

		if( empty( $auth_code ) || empty( $client_secret ) ){
            throw new Exception( "Authorisation code is empty." );
        }

        $response = wp_remote_get( "https://api.fortnox.se/3/", array( 'headers' => [
            'Authorization-Code' => $auth_code,
            'Client-Secret' => $client_secret,
            'Content-Type' => 'application/json',
            'Accept' => 'application/json'
        ] ) );

        fortnox_write_log( "get_access_token: " );
        fortnox_write_log( $response );

        $response = json_decode( $response['body'] );

		if( ! empty( $response->ErrorInformation ) ){
            throw new Exception( "{$response->ErrorInformation->Message} (Felkod: {$response->ErrorInformation->Code})" );

        }

		if( ! empty( $response->Authorization->AccessToken ) ){
            update_option( 'fortnox_access_token', $response->Authorization->AccessToken );
            update_option( 'fortnox_connected_organization_number', WF_Company_Information::get_organization_number() );
        }

		return $response->Authorization->AccessToken;
	}

    /**
     * Refreshes token
     */
    public static function refresh_token(){

        $headers = [
            'Content-type' =>  'application/x-www-form-urlencoded',
            'Authorization' =>  'Basic ' . base64_encode(self::CLIENT_ID . ':' . WF_Plugin::CLIENT_SECRET)
        ];

        $args = [
            'headers' => $headers,
            'body' => [
                'grant_type' => 'refresh_token',
                'refresh_token' => get_option('fortnox_refresh_token')
            ],
            'method' => 'POST',
            'data_format' => 'body'
        ];

        $response = wp_remote_post( self::REFRESH_URL, $args );
        $data = json_decode( $response['body'] );

        update_option( 'fortnox_access_token_oauth2', $data->access_token );
        update_option( 'fortnox_refresh_token', $data->refresh_token );
        update_option( 'fortnox_access_token_expiry_time', time() + ( 60 * 60 ) );

    }
}

